@@ -31,7 +31,7 @@ Glib::RefPtr<ExampleApplication> ExampleApplication::create()
 
 void ExampleApplication::create_window(const Glib::RefPtr<Gio::File>& file)
 {
-  ExampleWindow* window = new ExampleWindow();
+  auto window = new ExampleWindow();
 
   //Make sure that the application runs for as long this window is still open:
   add_window(*window);
@@ -77,7 +77,7 @@ void ExampleApplication::on_open(const Gio::Application::type_vec_files& files,
   //std::cout << "debug: files.size()=" << files.size() << std::endl;
   for(guint i = 0; i < files.size(); i++)
   {
-    Glib::RefPtr<Gio::File> file = files[i];
+    auto file = files[i];
     if(!file)
     {
       std::cerr << G_STRFUNC << ": file is null." << std::endl;
