@@ -91,19 +91,19 @@ void ExampleWindow::on_button_file_clicked()
 
   //Add filters, so that only certain file types can be selected:
 
-  Glib::RefPtr<Gtk::FileFilter> filter_text = Gtk::FileFilter::create();
+  auto filter_text = Gtk::FileFilter::create();
   filter_text->set_name("Text files");
   filter_text->add_mime_type("text/plain");
   dialog.add_filter(filter_text);
 
-  Glib::RefPtr<Gtk::FileFilter> filter_cpp = Gtk::FileFilter::create();
+  auto filter_cpp = Gtk::FileFilter::create();
   filter_cpp->set_name("C/C++ files");
   filter_cpp->add_mime_type("text/x-c");
   filter_cpp->add_mime_type("text/x-c++");
   filter_cpp->add_mime_type("text/x-c-header");
   dialog.add_filter(filter_cpp);
 
-  Glib::RefPtr<Gtk::FileFilter> filter_any = Gtk::FileFilter::create();
+  auto filter_any = Gtk::FileFilter::create();
   filter_any->set_name("Any files");
   filter_any->add_pattern("*");
   dialog.add_filter(filter_any);
