@@ -19,7 +19,6 @@
 ExampleWindow::ExampleWindow()
 : m_hbox(Gtk::ORIENTATION_HORIZONTAL, 6),
   m_show_desktop_check("Show \"Desktop\""),
-  m_show_connect_to_server_check("Show \"Connect to Server\""),
   m_show_enter_location("Show \"Enter Location\"")
 {
   // Window properties
@@ -37,9 +36,6 @@ ExampleWindow::ExampleWindow()
   m_show_desktop_check.signal_toggled().connect(sigc::mem_fun(*this, &ExampleWindow::on_show_desktop_toggled));
   m_show_desktop_check.set_active();
 
-  m_show_connect_to_server_check.signal_toggled().connect(sigc::mem_fun(*this, &ExampleWindow::on_show_connect_to_server_toggled));
-  m_show_connect_to_server_check.set_active();
-
   m_show_enter_location.signal_toggled().connect(sigc::mem_fun(*this, &ExampleWindow::on_show_enter_location_toggled));
   m_show_enter_location.set_active(false);
 
@@ -48,8 +44,7 @@ ExampleWindow::ExampleWindow()
   //m_places_sidebar.signal_drag_action_requested().connect(sigc::mem_fun(*this, &ExampleWindow::on_placessidebar_drag_action_requested));
 
   m_controls.attach(m_show_desktop_check, 0, 0, 1, 1);
-  m_controls.attach(m_show_connect_to_server_check, 0, 1, 1, 1);
-  m_controls.attach(m_show_enter_location, 0, 2, 1, 1);
+  m_controls.attach(m_show_enter_location, 0, 1, 1, 1);
 
   std::cout << "Shortcuts:" << std::endl;
   std::vector<Glib::RefPtr<Gio::File > > shortcuts = m_places_sidebar.list_shortcuts();
@@ -79,13 +74,6 @@ void ExampleWindow::on_show_desktop_toggled()
   m_places_sidebar.set_show_desktop(show_desktop);
 }
 
-void ExampleWindow::on_show_connect_to_server_toggled()
-{
-  const bool show_connect_to_server = m_show_connect_to_server_check.get_active();
-
-  m_places_sidebar.set_show_connect_to_server(show_connect_to_server);
-}
-
 void ExampleWindow::on_show_enter_location_toggled()
 {
   const bool show_enter_location = m_show_enter_location.get_active();
@@ -128,7 +116,7 @@ void ExampleWindow::on_placessidebar_open_location(const Glib::RefPtr<Gio::File>
 
 void ExampleWindow::on_placessidebar_populate_popup(Gtk::Menu* menu, const Glib::RefPtr<Gio::File>& /* selected_item */, const Glib::RefPtr<Gio::Volume>& /* selected_volume */)
 {
-  Gtk::MenuItem* properties_menu_item = new Gtk::MenuItem("Properties...");
+  auto properties_menu_item = new Gtk::MenuItem("Properties...");
 
   properties_menu_item->signal_activate().connect(sigc::mem_fun(*this, &ExampleWindow::on_menu_properties_activate));
   properties_menu_item->show();
@@ -138,7 +126,7 @@ void ExampleWindow::on_placessidebar_populate_popup(Gtk::Menu* menu, const Glib:
 
 void ExampleWindow::on_menu_properties_activate()
 {
-  Glib::RefPtr<Gio::File> selected_item = m_places_sidebar.get_location();
+  auto selected_item = m_places_sidebar.get_location();
 
   on_placessidebar_open_location(selected_item, Gtk::PLACES_OPEN_NORMAL);
 }
