@@ -51,7 +51,7 @@ ExampleWindow::ExampleWindow()
      {
         char buffer[32];
         sprintf(buffer, "button (%d,%d)\n", i, j);
-        Gtk::Button* pButton = Gtk::manage(new Gtk::ToggleButton(buffer));
+        auto pButton = Gtk::manage(new Gtk::ToggleButton(buffer));
         m_Grid.attach(*pButton, i, j, 1, 1);
      }
   }
