@@ -21,7 +21,7 @@
 
 int main (int argc, char *argv[])
 {
-  Glib::RefPtr<Gtk::Application> app = Gtk::Application::create(argc, argv, "org.gtkmm.example");
+  auto app = Gtk::Application::create(argc, argv, "org.gtkmm.example");
 
   DnDWindow dndWindow;
   return app->run(dndWindow); //Shows the window and returns when it is closed.
